@@ -12,12 +12,10 @@ class MaybeError(object):
 
     # must have same status and value to be equal
     def __eq__(self, other):
-        if self.status != other.status:
-            return False
-        return self.value == other.value
+        return self.__dict__ == other.__dict__
     
     def __ne__(self, other):
-        return self.__eq__(other)
+        return not self.__eq__(other)
     
     def fmap(self, f):
         if self.status == 'success':
